Function cwe_checker_lib::utils::arguments::parse_format_string_destination_and_return_content
source · pub fn parse_format_string_destination_and_return_content(
address: Bitvector,
runtime_memory_image: &RuntimeMemoryImage
) -> Result<String, Error>Expand description
Parses the destiniation address of the format string. It checks whether the address points to another pointer in memory. If so, it will use the target address of that pointer read the format string from memory.